.. _trojanvision.datasets.folder:

folder
=======
.. currentmodule:: trojanvision.datasets

.. autoclass:: CUB200
   :members:

.. autoclass:: CUB200_2011
   :members:

.. autoclass:: GTSRB
   :members:

.. autoclass:: ImageNet
   :members:

.. autoclass:: ISIC2018
   :members:

.. autoclass:: VGGface2
   :members:
